@@ -768,6 +768,137 @@ int mdecrypt_cfb(int td, void *plaintext,int len) /* plaintext is 1 byte (8bit c
 }
 
 
+/* OFB MODE */
+
+int end_mcrypt_ofb(int td)
+{
+
+free(s_register[td]);
+free(enc_s_register[td]);
+free(enc_sd_register[td]);
+free(sd_register[td]);
+
+return end_mcrypt(td);
+
+}
+
+
+int init_mcrypt_ofb(const int algorithm, void * key, int lenofkey, void *IV)
+{
+int x;
+
+#ifdef HAVE_LIBPTHREAD
+pthread_mutex_lock(&counter_cur_thread);
+#endif
+cur_thread++;
+
+
+if (cur_thread < MAX_THREADS && check_pointer[cur_thread]==0) {
+
+/* for ofb */
+  s_register=mxrealloc(s_register, (cur_thread+1) * sizeof(char*));
+  enc_s_register=mxrealloc(enc_s_register, (cur_thread+1) * sizeof(char*));  
+  enc_sd_register=mxrealloc(enc_sd_register, (cur_thread+1) * sizeof(char*));  
+  sd_register=mxrealloc(sd_register, (cur_thread+1) * sizeof(char*));
+/* end ofb */
+}
+else {
+  cur_thread=0;
+
+  while (check_pointer[cur_thread]==1 && cur_thread <= MAX_THREADS) {
+   cur_thread++;
+  }  
+
+  if (cur_thread >= MAX_THREADS) {
+    #ifdef HAVE_LIBPTHREAD
+    pthread_mutex_unlock(&counter_cur_thread);
+    #endif
+    return -1;
+  }
+}
+
+
+/* For cfb */
+  s_register[cur_thread]=mxmalloc( get_block_size(algorithm));
+  sd_register[cur_thread]=mxmalloc( get_block_size(algorithm));
+  enc_s_register[cur_thread]=mxmalloc( get_block_size(algorithm));
+  enc_sd_register[cur_thread]=mxmalloc( get_block_size(algorithm));
+  memmove(sd_register[cur_thread], IV, get_block_size(algorithm));
+  memmove(s_register[cur_thread], IV, get_block_size(algorithm));  
+
+/* End cfb */
+
+x=init_mcrypt( algorithm, cur_thread, key, lenofkey);
+
+ if (x<0) {
+   end_mcrypt_cfb(cur_thread);
+   #ifdef HAVE_LIBPTHREAD
+   pthread_mutex_unlock(&counter_cur_thread);
+   #endif
+   return -1;
+ }
+ else {
+   #ifdef HAVE_LIBPTHREAD
+   pthread_mutex_unlock(&counter_cur_thread);
+   #endif
+   return x;
+ }
+}
+
+int mcrypt_ofb(int td, void *plaintext,int len) /* plaintext is 1 byte (8bit cfb) */
+{
+  char* plain=plaintext;
+  int i,j,blocksize=get_block_size(algorithm_given[td]);;
+
+ for (j=0;j<len;j++) {
+  
+  memmove(enc_s_register[td], s_register[td], blocksize);
+  
+  mcrypt(td, enc_s_register[td]);
+
+  plain[j] ^= enc_s_register[td][0];
+  
+/* Shift the register */
+  for (i=0 ; i< (blocksize-1) ; i++) 
+    s_register[td][i]=s_register[td][i+1];
+  
+  s_register[td][blocksize-1]=enc_s_register[td][0];
+
+
+ }
+
+  return 0;
+
+}
+
+
+int mdecrypt_ofb(int td, void *plaintext,int len) /* plaintext is 1 byte (8bit cfb) */
+{
+  char* plain=plaintext;
+  int i,j,blocksize=get_block_size(algorithm_given[td]);;
+  
+ for (j=0;j<len;j++) {
+ 
+  memmove(enc_sd_register[td], sd_register[td], blocksize);
+
+  mcrypt(td, enc_sd_register[td]);
+
+/* Shift the register */
+  for (i=0 ; i<(blocksize-1) ; i++) 
+    sd_register[td][i]=sd_register[td][i+1];
+  
+  sd_register[td][blocksize-1]=enc_sd_register[td][0];
+
+  plain[j] ^= enc_sd_register[td][0];
+
+ }
+
+  return 0;
+}
+
+
+/* Extra functions */
+
 char* get_algorithms_name(int algorithm) {
 
 char *x=mxmalloc(12);
