@@ -27,6 +27,12 @@ int mcrypt_cfb(int td, void *plaintext,int len);
 int mdecrypt_cfb(int td, void *ciphertext, int len);
 int init_mcrypt_cfb( const int algorithm, void * key, int lenofkey, void *IV);
 
+/* OFB */
+int end_mcrypt_ofb(int td);
+int mcrypt_ofb(int td, void *plaintext,int len);
+int mdecrypt_ofb(int td, void *ciphertext, int len);
+int init_mcrypt_ofb( const int algorithm, void * key, int lenofkey, void *IV);
+
 
 # define BLOWFISH 0
 # define DES 1 
